@@ -8,7 +8,7 @@ use LWP::UserAgent qw//;
 use HTTP::Request  qw//;
 use URI::Encode    qw/uri_encode/;
 use URI::Escape    qw/uri_escape/; # next update, also line 122
-use Data::Dump::Color;
+#use Data::Dump::Color;
 
 require Reddit::Client;
 
